you can install the package with pip

    pip install mj_package

Example for use : 
   
    >>> from mj_package import proclamer
    >>> proclamer()

Code under WTPFL licence

pip install git+ssh://git@gitlab.com/Training_Dev_Ops/creating_package.git